<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="description" content="A Sample Client that lets you compare emails you would grant access to with or without PePr">
        <meta name="viewport" content="width=device-width, initial-scale=1.0, minimum-scale=1.0">
        <title>Demo: Pig Latin translation microservice</title>
        <link rel="stylesheet" href="https://fonts.googleapis.com/icon?family=Material+Icons">
        <link rel="stylesheet" href="https://code.getmdl.io/1.1.3/material.indigo-pink.min.css">
        <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='style.css') }}">
        <script defer src="https://code.getmdl.io/1.1.3/material.min.js"></script>
    </head>
    <body>
        <div class="mdl-layout mdl-js-layout">
            <header class="mdl-layout__header">
                <div class="mdl-layout-icon"></div>
                <div class="mdl-layout__header-row">
                    <span class="mdl-layout__title">Pig Latin Microservice</span>
                    <div class="mdl-layout-spacer"></div>
                    <nav class="mdl-navigation">
                        <a class="mdl-navigation__link" href="http://pig-latin-translation-microservice.readthedocs.io">Documentation</a>
                        <a class="mdl-navigation__link" href="https://github.com/Jai-Chaudhary/pig-latin-translation-microservice">View Source</a>
                    </nav>
                </div>
            </header>
            <div class="mdl-layout__drawer">
                <span class="mdl-layout__title">Pig Latin</span>
                <nav class="mdl-navigation">
                    <a class="mdl-navigation__link" href="http://pig-latin-translation-microservice.readthedocs.io">Documentation</a>
                    <a class="mdl-navigation__link" href="https://github.com/Jai-Chaudhary/pig-latin-translation-microservice">View Source</a>
                </nav>
            </div>
            <main class="mdl-layout__content">
                {% block content %}
                {% endblock %}
            </main>
        </div>
    </body>
</html>
